pub struct StringParameter(/* private fields */);Expand description
Represents string parameters of many different types.
Implementations
Sourceimpl StringParameter
impl StringParameter
Sourcepub fn set(&self, index: i32, value: impl AsRef<str>) -> Result<()>
pub fn set(&self, index: i32, value: impl AsRef<str>) -> Result<()>
Set parameter value at index.
Sourcepub fn set_array<T: AsRef<str>>(&self, val: impl AsRef<[T]>) -> Result<()>
pub fn set_array<T: AsRef<str>>(&self, val: impl AsRef<[T]>) -> Result<()>
Set all parameter tuple values
Sourcepub fn save_parm_file(
&self,
destination_dir: &Path,
filename: &str,
) -> Result<()>
pub fn save_parm_file( &self, destination_dir: &Path, filename: &str, ) -> Result<()>
Save/Download a file referenced in this parameter to a given file.
filename must include the desired extension to work properly.
Sourcepub fn set_value_as_node(&self, value: impl AsRef<NodeHandle>) -> Result<()>
pub fn set_value_as_node(&self, value: impl AsRef<NodeHandle>) -> Result<()>
If parameter is a ParmType::Node type, set it to reference another node
Sourcepub fn get_value_as_node(&self) -> Result<Option<NodeHandle>>
pub fn get_value_as_node(&self) -> Result<Option<NodeHandle>>
Return a handle to a node if the parameter is of type ParmType::Node