pub struct SessionOptions {
pub cook_opt: CookOptions,
pub threaded: bool,
pub cleanup: bool,
pub env_files: Option<CString>,
pub otl_path: Option<CString>,
pub dso_path: Option<CString>,
pub img_dso_path: Option<CString>,
pub aud_dso_path: Option<CString>,
}Expand description
Session options passed to session create functions like crate::server::connect_to_pipe_server
Fields
cook_opt: CookOptionsSession cook options
threaded: boolCreate a Threaded server connection
cleanup: boolCleanup session upon close
env_files: Option<CString>otl_path: Option<CString>dso_path: Option<CString>img_dso_path: Option<CString>aud_dso_path: Option<CString>Implementations
Sourceimpl SessionOptions
impl SessionOptions
Sourcepub fn houdini_env_files<I>(self, files: I) -> Self
pub fn houdini_env_files<I>(self, files: I) -> Self
A list of Houdini environment files the Engine will load from.
Panics
Panics if the joined path list contains an interior null byte.
Sourcepub fn otl_search_paths<I>(self, paths: I) -> Self
pub fn otl_search_paths<I>(self, paths: I) -> Self
Add search paths for the Engine to find HDAs.
Panics
Panics if the joined path list contains an interior null byte.
Sourcepub fn dso_search_paths<P>(self, paths: P) -> Self
pub fn dso_search_paths<P>(self, paths: P) -> Self
Add search paths for the Engine to find DSO plugins.
Panics
Panics if the joined path list contains an interior null byte.
Sourcepub fn image_search_paths<P>(self, paths: P) -> Self
pub fn image_search_paths<P>(self, paths: P) -> Self
Add search paths for the Engine to find image plugins.
Panics
Panics if the joined path list contains an interior null byte.
Sourcepub fn audio_search_paths<P>(self, paths: P) -> Self
pub fn audio_search_paths<P>(self, paths: P) -> Self
Add search paths for the Engine to find audio files.
Panics
Panics if the joined path list contains an interior null byte.
Sourcepub fn cook_options(self, options: CookOptions) -> Self
pub fn cook_options(self, options: CookOptions) -> Self
Pass session CookOptions