String handling utilities and iterators
Structs
- CString
Iter - Iterator over
CStringsreturned fromStringArray::iter_cstr() - Owned
String Iter - Consuming iterator over String, returned from
StringArray::into_iter() - String
Array - Holds a contiguous array of bytes where each individual string value is null-separated.
You can choose how to iterate over it by calling a corresponding iter_* function.
The
Debugimpl has an alternative{:#?}representation, which prints as a vec of strings. - String
Handle - A handle to a string returned by some api.
Then the String can be retrieved with
Session::get_string - String
Iter - Iterator over &str, returned from
StringArray::iter_str()